<?php

namespace Drupal\drupalfit\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DrupalfitConfigurationForm to add/update authorization key.
 *
 * @package Drupal\drupalfit\Form
 */
class DrupalfitConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'drupalfit_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'drupalfit.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('drupalfit.settings');
    $form['base_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Base Url'),
      '#default_value' => $config->get('base_url'),
      '#description' => $this->t('Enter site base url without https and www where you want to access this api. (Maxlength: 50)'),
      '#maxlength' => 50,
      '#required' => TRUE,
    ];
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('System report api authentication key. (Maxlength: 50)'),
      '#maxlength' => 40,
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('drupalfit.settings')
      ->set('base_url', $form_state->getValue('base_url'))
      ->set('api_key', $form_state->getValue('api_key'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
